pub struct ExtendKeyed<S, K> { /* private fields */ }Available on crate features
std or unstable only.Trait Implementations
Sourceimpl<S: Default, K> Default for ExtendKeyed<S, K>
impl<S: Default, K> Default for ExtendKeyed<S, K>
Sourceimpl<S: ExtendPinned<T>, K, T> ExtendPinned<(K, T)> for ExtendKeyed<S, K>
impl<S: ExtendPinned<T>, K, T> ExtendPinned<(K, T)> for ExtendKeyed<S, K>
Sourcefn extend_pinned<I: IntoIterator<Item = (K, T)>>(self: Pin<&mut Self>, iter: I)
fn extend_pinned<I: IntoIterator<Item = (K, T)>>(self: Pin<&mut Self>, iter: I)
Extend::extend equivalent for Pin<&mut I>.Sourceimpl<Route, Msg, S: FlushRoute<Route, Msg>, K> FlushRoute<Route, Msg> for ExtendKeyed<S, K>
Available on crate feature route-sink only.
impl<Route, Msg, S: FlushRoute<Route, Msg>, K> FlushRoute<Route, Msg> for ExtendKeyed<S, K>
Available on crate feature
route-sink only.Sourceimpl<S, K> From<S> for ExtendKeyed<S, K>
impl<S, K> From<S> for ExtendKeyed<S, K>
Sourceimpl<S: FusedStream, K> FusedStream for ExtendKeyed<S, K>
impl<S: FusedStream, K> FusedStream for ExtendKeyed<S, K>
Sourcefn is_terminated(&self) -> bool
fn is_terminated(&self) -> bool
Returns
true if the stream should no longer be polled.Sourceimpl<Route, Msg, S: ReadyRoute<Route, Msg>, K> ReadyRoute<Route, Msg> for ExtendKeyed<S, K>
Available on crate feature route-sink only.
impl<Route, Msg, S: ReadyRoute<Route, Msg>, K> ReadyRoute<Route, Msg> for ExtendKeyed<S, K>
Available on crate feature
route-sink only.Sourceimpl<Route, Msg, S: ReadySome<Route, Msg>, K> ReadySome<Route, Msg> for ExtendKeyed<S, K>
Available on crate feature route-sink only.
impl<Route, Msg, S: ReadySome<Route, Msg>, K> ReadySome<Route, Msg> for ExtendKeyed<S, K>
Available on crate feature
route-sink only.Sourceimpl<Item, S: Sink<Item>, K> Sink<Item> for ExtendKeyed<S, K>
Available on crate feature sink only.
impl<Item, S: Sink<Item>, K> Sink<Item> for ExtendKeyed<S, K>
Available on crate feature
sink only.Sourcetype Error = <S as Sink<Item>>::Error
type Error = <S as Sink<Item>>::Error
The type of value produced by the sink when an error occurs.
Sourcefn poll_ready(
self: Pin<&mut Self>,
cx: &mut Context<'_>,
) -> Poll<Result<(), Self::Error>>
fn poll_ready( self: Pin<&mut Self>, cx: &mut Context<'_>, ) -> Poll<Result<(), Self::Error>>
Attempts to prepare the
Sink to receive a value. Read moreSourcefn start_send(self: Pin<&mut Self>, item: Item) -> Result<(), Self::Error>
fn start_send(self: Pin<&mut Self>, item: Item) -> Result<(), Self::Error>
Begin the process of sending a value to the sink.
Each call to this function must be preceded by a successful call to
poll_ready which returned Poll::Ready(Ok(())). Read moreSourceimpl<S: Stream, K> Stream for ExtendKeyed<S, K>
impl<S: Stream, K> Stream for ExtendKeyed<S, K>
impl<'pin, S, K> Unpin for ExtendKeyed<S, K>where
PinnedFieldsOf<__ExtendKeyed<'pin, S, K>>: Unpin,